@@ -11,12 +11,12 @@ wget -N http://git.savannah.gnu.org/cgit/config.git/plain/config.guess \
 cd ..
 echo ''
 for FNAME in config.guess config.sub install-sh missing mkinstalldirs ; do
-  cmp -s ${FNAME} tmp/${FNAME}
-  if [ "X$?" = "X0" ]; then
-    echo "... skipping ${FNAME}"
+  cmp -s "$FNAME" "tmp/${FNAME}"
+  if [ $? -eq 0 ]; then
+    echo "... skipping $FNAME"
   else
-    echo "... updating ${FNAME}"
-    cp tmp/${FNAME} .
+    echo "... updating $FNAME"
+    cp "tmp/${FNAME}" .
   fi
 done
 rm -rf tmp
